@@ -5,7 +5,7 @@ use DBIx::Custom::Model -base;
 sub insert {
     my ($self, $param) = @_;
     
-    return $self->SUPER::insert($param);
+    return $self->SUPER::insert(param => $param);
 }
 
 sub list { shift->select; }
